@@ -112,6 +112,9 @@ is_close:{is_close}
         :param message: 用户指定的日志内容
         :return:
         """
+        # 去除 '\n'
+        message = message.replace('\n', '')
+
         caller = getframeinfo(stack()[1][0])
         # self.__send(message=message, is_close=0, filename=caller.filename, lineno=caller.lineno)
         self.pool.submit(self.__send, message=message, is_close=0, filename=caller.filename, lineno=caller.lineno)
@@ -127,7 +130,7 @@ is_close:{is_close}
 def test():
     client = EasyLog(name='log-server', host='127.0.0.1', port=10000, absolute_path='/Users/tiger/develop/tmp')
 
-    for _ in range(300):
+    for _ in range(999999):
         client.send(message='下载图片成功')
 
     import time
